<?php

   function setPrice($price = null) {
	
	$currency = get_field('pro_currency', 'option');
	$thousands_separator = get_field('thousands_separator', 'option');
	$decimal_separator = get_field('decimal_separator', 'option');
	$currency = (!empty($currency) ? $currency : 'R$ ');
	$decimalSeparator = (!empty($decimal_separator) ? $decimal_separator : ',');
	$thousandsSeparator = (!empty($thousands_separator) ? $thousands_separator : '.');

    if (!empty($price)) {

        $price = substr($price, 0, strpos($price, $decimalSeparator));
        $price = str_replace($thousandsSeparator, '', $price);
        $price = str_replace($currency, '', $price);
    }

    return $price;
  }

  add_action('pre_get_posts', 'advanced_search_query');

   function advanced_search_query($query) {
	   
    if (isset($_REQUEST['imovel']) && $_REQUEST['imovel'] == 'pesquisa' && !is_admin() && $query->is_search && $query->is_main_query()) {
        $query->set('post_type', 'post');
        $business = isset($_REQUEST['business']) ? $_REQUEST['business'] : '';
        $code = sanitize_text_field(isset($_REQUEST['code'])) != '' ? sanitize_text_field($_REQUEST['code']) : false;
        $tipo = isset($_REQUEST['tipo']) ? $_REQUEST['tipo'] : false;
        $quarto = isset($_REQUEST['quarto']) != '' ? $_REQUEST['quarto'] : false;
        $banheiro = isset($_REQUEST['banheiro']) ? $_REQUEST['banheiro'] : false;
        $garagem = isset($_REQUEST['garagem']) ? $_REQUEST['garagem'] : false;
        $vlMin = sanitize_text_field(isset($_REQUEST['valor_min'])) ? sanitize_text_field(setPrice($_REQUEST['valor_min'])) : (sanitize_text_field(isset($_REQUEST['valor_min'])) == 'R$ 0,00' ? false : false);
        $vlMax = sanitize_text_field(isset($_REQUEST['valor_max'])) ? sanitize_text_field(setPrice($_REQUEST['valor_max'])) : (sanitize_text_field(isset($_REQUEST['valor_max'])) == 'R$ 0,00' ? false : false);
        $cidade = isset($_REQUEST['cidade']) ? $_REQUEST['cidade'] : false;
        $bairro = isset($_REQUEST['bairro']) ? $_REQUEST['bairro'] : false;
        $city = isset($_REQUEST['city']) ? $_REQUEST['city'] : false;
        $neighborhood = isset($_REQUEST['neighborhood']) ? $_REQUEST['neighborhood'] : false;
        $filter = isset($_REQUEST['order']) ? $_REQUEST['order'] : false;
        $order = $filter === 'areaDesc' || $filter === 'priceDesc' ? 'DESC' : 'ASC';
        $filter = $filter === 'priceAsc' || $filter === 'priceDesc' ? 'valor' : ($filter === 'areaAsc' || $filter === 'areaDesc' ? 'total_area' : ($filter === 'relevance' ? 'relevance' : 'valor'));
        $args = array();
		
        if (!empty($business)):
            $args['tax_query'][] = array(
                'taxonomy' => 'type_of_business',
                'field' => 'slug',
                'terms' => $business,
                'compare' => '=',
            );
        endif;

        if (!empty($tipo)) :
            $args['tax_query'][] = array(
                'taxonomy' => 'category', 'field' => 'slug', 'terms' => $tipo
            );
        endif;



        if (!empty($code)):
            $args['meta_query'][] = array(
                'key' => 'code_id_property', 'value' => $code, 'type' => 'CHAR', 'compare' => '='
            );
        endif;

        if (!empty($quarto)) :
            $args['meta_query'][] = array(
                'key' => 'bedroom', 'value' => $quarto, 'type' => 'NUMERIC', 'compare' => '='
            );
        endif;

        if (!empty($banheiro)) :
            $args['meta_query'][] = array(
                'key' => 'bathroom', 'value' => $banheiro, 'type' => 'NUMERIC', 'compare' => '='
            );
        endif;


        if (!empty($garagem)) :
            $args['meta_query'][] = array(
                'key' => 'garage', 'value' => $garagem, 'type' => 'NUMERIC', 'compare' => '='
            );
        endif;

        if (!empty($vlMin) AND ( !empty($vlMax))):
            $args['meta_query'][] = array(
                'key' => 'valor',
                'value' => array($vlMin, $vlMax),
                'type' => 'NUMERIC',
                'compare' => 'BETWEEN'
            );
        elseif (!empty($vlMin)):
            $args['meta_query'][] = array(
                'key' => 'valor',
                'value' => $vlMin,
                'type' => 'NUMERIC',
                'compare' => '>='
            );
        elseif (!empty($vlMax)):
            $args['meta_query'][] = array(
                'key' => 'valor',
                'value' => $vlMax,
                'type' => 'NUMERIC',
                'compare' => '<='
            );
        endif; //end price

        if (!empty($cidade)):
            $args['tax_query'][] = array(
                'taxonomy' => 'cidades',
                'field' => 'slug',
                'terms' => $cidade,
                'compare' => 'LIKE',
            );
        endif;
        $args['meta_query'][] = array(
            'key' => 'bairro',
            'value' => $bairro,
            'compare' => 'LIKE',
        );
        if (!empty($city)):
            $args['tax_query'][] = array(
                'taxonomy' => 'cidades',
                'field' => 'slug',
                'terms' => $city,
                'compare' => 'LIKE',
            );
        endif;
        $args['meta_query'][] = array(
            'key' => 'bairro',
            'value' => $neighborhood,
            'compare' => 'LIKE',
        );
        $query->set('tax_query', $args);
        $query->set('meta_query', $args);
        $query->set('meta_key', $filter);
        $query->set('orderby', 'meta_value_num');
        $query->set('order', $order);
        $query->set('posts_per_page', 6);
    }
}

// Change posts per page in the design category
add_action('pre_get_posts', 'design_cat_posts_per_page');

function design_cat_posts_per_page($query) {

    if ($query->is_main_query() && is_category() && !is_admin()) {

        $filter = isset($_REQUEST['order']) ? $_REQUEST['order'] : false;
        $order = $filter === 'areaDesc' || $filter === 'priceDesc' ? 'DESC' : 'ASC';
        $filter = $filter === 'priceAsc' || $filter === 'priceDesc' ? 'valor' : ($filter === 'areaAsc' || $filter === 'areaDesc' ? 'total_area' : ($filter === 'relevance' ? 'relevance' : 'valor'));

        $query->set('meta_key', $filter);
        $query->set('orderby', 'meta_value_num');
        $query->set('order', $order);
        $query->set('posts_per_page', 6);
    }
}

// Change posts per page in the design taxonomy
add_action('pre_get_posts', 'design_tax_posts_per_page');

function design_tax_posts_per_page($query) {

    if ($query->is_main_query() && is_tax('type_of_business') && !is_admin()) {

        $filter = isset($_REQUEST['order']) ? $_REQUEST['order'] : false;
        $order = $filter === 'areaDesc' || $filter === 'priceDesc' ? 'DESC' : 'ASC';
        $filter = $filter === 'priceAsc' || $filter === 'priceDesc' ? 'valor' : ($filter === 'areaAsc' || $filter === 'areaDesc' ? 'total_area' : ($filter === 'relevance' ? 'relevance' : 'valor'));

        $query->set('meta_key', $filter);
        $query->set('orderby', 'meta_value_num');
        $query->set('order', $order);
        $query->set('posts_per_page', 6);
    }
}

//* Remove pages from search results
add_filter('pre_get_posts', 'page_search_exclude');

function page_search_exclude($query) {
    if ($query->is_main_query() && !is_admin()) {
        if ($query->is_search) {
            $filter = isset($_REQUEST['order']) ? $_REQUEST['order'] : false;
            $order = $filter === 'areaDesc' || $filter === 'priceDesc' ? 'DESC' : 'ASC';
            $filter = $filter === 'priceAsc' || $filter === 'priceDesc' ? 'valor' : ($filter === 'areaAsc' || $filter === 'areaDesc' ? 'total_area' : ($filter === 'relevance' ? 'relevance' : 'valor'));

            $query->set('post_type', 'post');
            $query->set('meta_key', $filter);
            $query->set('orderby', 'meta_value_num');
            $query->set('order', $order);
            $query->set('posts_per_page', 6);
        }
    }
    return $query;
}
