<?php
if (!defined('ABSPATH')) {
    exit;
}
?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
    <head>
        <meta charset="<?php bloginfo('charset'); ?>">
        <meta name="viewport" content="width=device-width,initial-scale=1">
        <?php $pro_add_open_graph = get_field('enable_open_graph', 'option'); ?>
        <?php
        if (!empty($pro_add_open_graph)) {
            get_template_part('/includes/config-seo');
        }
        ?>
        <meta property="og:image" content="<?php echo pro_custom_img('full', 600, 315); ?>" />
        <meta name="twitter:image" content="<?php echo pro_custom_img('full', 600, 315); ?>" />
        <!--[if lt IE 9]>
        <script src="<?php echo get_template_directory_uri(); ?>/cdn/html5shiv.js"></script>
        <![endif]-->   
        <?php wp_head(); ?>
        <!-- Favicon -->
        <?php if (get_field('pro_favicon', 'option') <> "") { ?>
            <link rel="shortcut icon" href="<?php echo get_field('pro_favicon', 'option'); ?>" />
        <?php } else { ?>
            <link rel="shortcut icon" href="<?php bloginfo('template_directory'); ?>/img/favicon.png" />
        <?php } ?>
        <?php
        $codigo = get_field('pro_google_analytics', 'option');

        if ($codigo != '') {
            echo strip_tags($codigo, '<script>');
        }
        ?>
    </head>
    <body <?php body_class(); ?>>
        <?php if (is_home() || is_front_page()) { ?>
            <header>
                <h1 class="main_title"><?php bloginfo('description'); ?> - <?php bloginfo('name'); ?></h1>
            </header>
        <?php } elseif (is_category()) { ?>
            <header>
                <h1 class="main_title">Categoria de imóveis - <?php single_cat_title(); ?></h1>
            </header>
        <?php } elseif (is_search()) { ?>
            <header>
                <h1 class="main_title">Resultado da pesquisa</h1>
            </header>
        <?php } elseif (is_404()) { ?>
            <header>
                <h1 class="main_title">Página não encontrada</h1>
            </header>
        <?php } elseif (is_single()) { ?>
            <header>
                <h1 class="main_title"><?php the_title(); ?></h1>
            </header>
        <?php } else { ?>
            <header>
                <h1 class="main_title">Página <?php the_title(); ?></h1>
            </header>
        <?php } ?>
        <!--  MENU-->
        <?php
        $phoneNumberMenu = get_field('phone_number', 'option');
		$attendanceTop = get_field('service_number_top', 'option');
		$text_attendance_top = get_field('text_attendance_top', 'option');
		$icon_attendance_top = get_field('icon_attendance_top', 'option');
		$chat_number_whatsapp = get_field('chat_number_whatsapp', 'option');
        $chat_number_whatsapp = (!empty($chat_number_whatsapp)) ? $chat_number_whatsapp : false;
		$telephoneNumber = preg_replace("/[^0-9]/", "", $phoneNumberMenu);
        ?>
        <div class="menu_mobile container">
            <ul class="content-menu">
                <li>
                    <a href="#" class="mobile_action" title="Menu"><i class="fa fa-bars fa-fw"></i></a>
                </li>				
                <?php if (!empty($phoneNumberMenu)) { ?>			
                    <li id="open_tel">
                        <a href="#" class="open_tel" title="Atendimento"><i class="fa fa-phone fa-fw"></i></a>
                        <ul class="menu_view">
                            <li class="atendimento">
                                <strong> - Atendimento</strong><br><a href="tel:55<?php echo $telephoneNumber; ?>"><?php echo $phoneNumberMenu; ?></a>
                            </li>	
                        </ul>
                    </li>	
                <?php } ?>	
                <?php if (!empty($attendanceTop)) { ?>					   
                    <li id="open_whatsapp">
                        <a target="_blank" href="https://api.whatsapp.com/send?phone=<?php echo $chat_number_whatsapp; ?>" class="open_whatsapp" title="<?php echo $text_attendance_top; ?>"><i class="<?php echo $icon_attendance_top; ?> fa-fw"></i></a>
                    </li>
                <?php } ?>
                <li><a href="<?php echo esc_url(home_url('/contato')); ?>" title="Contato"><i class="fa fa-envelope fa-fw"></i></a></li>
                <li><a href="<?php echo esc_url(home_url('/meus-favoritos')); ?>" title="Favoritos"><i class="fa fa-heart-o fa-fw"></i></a></li>
                <li>
                    <?php if (!is_search() && !is_archive() && !is_category()) { ?>
                        <a href="#" class="art_search" title="Pesquisar"><i class="fa fa-search fa-fw"></i></a>
                    <?php } else { ?>
                        <a href="#" class="filter_search" title="Exibir filtros"><i class="fa fa-search fa-fw"></i></a>
                    <?php } ?>
                </li>
            </ul>
        </div>		
        <header class="main_header container bg-custom-top">
            <div class="content content_header">
                <div class="main_header_logo box_header">
                    <a href="<?php echo home_url(); ?>" title="<?php bloginfo('name'); ?>">
                        <?php if (get_field('pro_logo', 'option') <> "") : ?>
                            <img src="<?php echo get_field('pro_logo', 'option'); ?>" alt="<?php
                            bloginfo('name');
                            bloginfo('description');
                            ?>" title="<?php bloginfo('name'); ?>" >
                             <?php else: ?>
                            <p class="text_logo"><?php echo bloginfo('name'); ?></p>
                        <?php endif; ?>
                    </a>
                </div>
                <?php
                $show_contacts_top = get_field('show_contacts_top', 'option');
                if (!empty($show_contacts_top)) {
                    get_template_part('includes/box-contacts-top');
                }
                ?>
                <div class="clear"></div>
            </div>
        </header>
        <div id="second_header">
            <div class="content content_header">
                <div class="main_header_logo box_header">
                    <a href="<?php echo home_url(); ?>" title="<?php bloginfo('name'); ?>">
                        <?php if (get_field('pro_logo', 'option') <> "") : ?>
                            <img src="<?php echo get_field('pro_logo', 'option'); ?>" alt="<?php
                            bloginfo('name');
                            bloginfo('description');
                            ?>" title="<?php bloginfo('name'); ?>" >
                             <?php else: ?>
                            <p class="text_logo"><?php echo bloginfo('name'); ?></p>
                        <?php endif; ?>
                    </a>
                </div>
                <?php
                $show_contacts_top = get_field('show_contacts_top', 'option');
                if (!empty($show_contacts_top)) {
                    get_template_part('includes/box-contacts-top');
                }
                ?>
                <div class="clear"></div>
            </div>
        </div>
        <!--  MENU-->
        <div class="menu_header container bg-menu-color">
            <div id="call_info" class="content-menu">
                <ul class="call_info">
                    <?php echo pro_login_head(); ?>
                </ul>
            </div>
            <?php if (has_nav_menu('topnav')) { ?>
                <?php wp_nav_menu(array('menu_class' => 'main_nav content-menu', 'container' => 'ul', 'theme_location' => 'topnav')); ?>
            <?php } else { ?>
                <ul class="main_nav content-menu">
                    <li>
                        <a href="<?php echo home_url(); ?>"><?php _e('Home', 'proimovel'); ?></a>
                    </li>
                    <?php
                    wp_list_categories(array('depth' => 0, 'number' => 19,
                        'title_li' => false,
                        'hierarchical' => 1));
                    ?>                 
                </ul><!--menu-->
            <?php } ?>

            <div class="clear"></div>
        </div>
        <?php
        $active_capture_popup = get_field('active_capture_popup', 'option');
        if (!empty($active_capture_popup) && is_home()) {
            get_template_part('includes/form-popup');
        }
        ?>

        <?php if (is_front_page() || is_home()) { ?>
            <?php get_template_part('slide-home'); ?>
        <?php } ?>
        <?php if (!is_search() && !is_archive()) { ?>
            <div id="ad_search" class="container">
                <?php get_template_part('search-imovel'); ?>
            </div>
        <?php } ?>